:github_url: https://github.com/stephane-caron/pink/tree/main/doc/developer-notes.rst

***************
Developer notes
***************

This section documents internal functions and other notes shared between contributors to this project.

Design guidelines
=================

* Pink is designed for clarity before performance
* Leaky abstractions are our enemy
* WIP

Exceptions
==========

.. automodule:: pink.exceptions
    :members:
